==> klavaro-1.0.3.tar.bz2: klavaro-1.0.3/src/translation.h <==
/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

/*
 * This file contains the set of languages configured for
 * internationalization.
 * The letters in parenthesis must agree with LL_CC,
 * where LL is the language code
 * and CC is the country code.
 * The only one exception is for the US English,
 * which uses the 'C' code.
 * Keep the alphabetic order, because it is put
 * in the interface as done here.
 */

#define LANG_SET \
"Čeština (cs_CZ)\n" \
"English (C)\n" \
"Español (es_ES)\n" \
"Esperanto (eo_EO)\n" \
"Deutsch (de_DE)\n" \
"Français (fr_FR)\n" \
"Magyar (hu_HU)\n" \
"Nederlands - België (nl_BE)\n" \
"Nederlands - Nederland (nl_NL)\n" \
"Polski (pl_PL)\n" \
"Português - Brasil (pt_BR)\n" \
"Svenska (sv_SE)";

#define LANG_NAME_MAX_LEN 50
typedef struct
{
	gchar name[LANG_NAME_MAX_LEN];
	gchar code[6];
} Lang_Name_Code;

void trans_set_language_env (gchar * code);

void trans_init_lang_name_code (void);

void trans_init_language_env (void);

void trans_set_combo_language (void);

void trans_change_language (void);

FILE *trans_lang_get_similar_file (const gchar * file_end);

void trans_read_text (gchar *, gint, const gchar *);

==> klavaro-1.0.4.tar.bz2: klavaro-1.0.4/src/translation.h <==
/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2007  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

/*
 * This file contains the set of languages configured for
 * internationalization.
 * The letters in parenthesis must agree with LL_CC,
 * where LL is the language code
 * and CC is the country code.
 * The only one exception is for the US English,
 * which uses the 'C' code.
 * Keep the alphabetic order, because it is put
 * in the interface as done here.
 */

#define LANG_SET \
"Čeština (cs_CZ)\n" \
"English (C)\n" \
"Español (es_ES)\n" \
"Esperanto (eo_XX)\n" \
"Deutsch (de_DE)\n" \
"Français (fr_FR)\n" \
"Magyar (hu_HU)\n" \
"Nederlands - België (nl_BE)\n" \
"Nederlands - Nederland (nl_NL)\n" \
"Polski (pl_PL)\n" \
"Português - Brasil (pt_BR)\n" \
"Svenska (sv_SE)";

#define LANG_NAME_MAX_LEN 50
typedef struct
{
	gchar name[LANG_NAME_MAX_LEN];
	gchar code[6];
} Lang_Name_Code;

void trans_set_language_env (gchar * code);

void trans_init_lang_name_code (void);

void trans_init_language_env (void);

void trans_set_combo_language (void);

void trans_change_language (void);

FILE *trans_lang_get_similar_file (const gchar * file_end);

void trans_read_text (gchar *, gint, const gchar *);
